@@ -91,6 +91,9 @@ void PointerCoordinatesWindow::createDialogContent()
 	ui->checkBoxConstellation->setChecked(coord->getFlagShowConstellation());
 	connect(ui->checkBoxConstellation, SIGNAL(toggled(bool)), coord, SLOT(setFlagShowConstellation(bool)));
 
+	ui->checkBoxCrossedLines->setChecked(coord->getFlagShowCrossedLines());
+	connect(ui->checkBoxCrossedLines, SIGNAL(toggled(bool)), coord, SLOT(setFlagShowCrossedLines(bool)));
+
 	connect(ui->spinBoxX, SIGNAL(valueChanged(int)), this, SLOT(setCustomCoordinatesPlace()));
 	connect(ui->spinBoxY, SIGNAL(valueChanged(int)), this, SLOT(setCustomCoordinatesPlace()));
 
@@ -119,7 +122,9 @@ void PointerCoordinatesWindow::setAboutHtml(void)
 	QString html = "<html><head></head><body>";
 	html += "<h2>" + q_("Pointer Coordinates plug-in") + "</h2><table width=\"90%\">";
 	html += "<tr width=\"30%\"><td><strong>" + q_("Version") + ":</strong></td><td>" + POINTERCOORDINATES_PLUGIN_VERSION + "</td></tr>";
+	html += "<tr><td><strong>" + q_("License") + ":</strong></td><td>" + POINTERCOORDINATES_PLUGIN_LICENSE + "</td></tr>";
 	html += "<tr><td><strong>" + q_("Author") + ":</strong></td><td>Alexander Wolf &lt;alex.v.wolf@gmail.com&gt;</td></tr>";
+	html += "<tr><td><strong>" + q_("Contributors") + ":</strong></td><td>Georg Zotti</td></tr>";
 	html += "</table>";
 
 	html += "<p>" + q_("Show coordinates of the mouse cursor on the screen.");
@@ -175,6 +180,7 @@ void PointerCoordinatesWindow::populateCoordinatesPlacesList()
 	places->addItem(q_("The top center of the screen"), "TopCenter");
 	places->addItem(q_("In center of the top right half of the screen"), "TopRight");
 	places->addItem(q_("The right bottom corner of the screen"), "RightBottomCorner");
+	places->addItem(q_("Near mouse cursor"), "NearMouseCursor");
 	places->addItem(q_("Custom position"), "Custom");
 
 	//Restore the selection
