@@ -54,8 +54,11 @@ SatellitesDialog::SatellitesDialog()
 	, importWindow(Q_NULLPTR)
 	, filterModel(Q_NULLPTR)
 	, checkStateRole(Qt::UserRole)
+	, delimiter(", ")
+	, acEndl("\n")
 {
 	ui = new Ui_satellitesDialog;
+	iridiumFlaresHeader.clear();
 }
 
 SatellitesDialog::~SatellitesDialog()
@@ -105,6 +108,9 @@ void SatellitesDialog::createDialogContent()
 	QList<QWidget *> addscroll;
 	addscroll << ui->satellitesList << ui->sourceList << ui->aboutTextBrowser;
 	installKineticScrolling(addscroll);
+	acEndl="\r\n";
+#else
+	acEndl="\n";
 #endif
 
 	// Settings tab / updates group
@@ -227,10 +233,46 @@ void SatellitesDialog::createDialogContent()
 	initListIridiumFlares();
 	ui->flaresPredictionDepthSpinBox->setValue(plugin->getIridiumFlaresPredictionDepth());
 	connect(ui->flaresPredictionDepthSpinBox, SIGNAL(valueChanged(int)), plugin, SLOT(setIridiumFlaresPredictionDepth(int)));
-	connect(ui->pushButtonPredictIridiumFlares, SIGNAL(clicked()), this, SLOT(predictIridiumFlares()));
+	connect(ui->predictIridiumFlaresPushButton, SIGNAL(clicked()), this, SLOT(predictIridiumFlares()));
+	connect(ui->predictedIridiumFlaresSaveButton, SIGNAL(clicked()), this, SLOT(savePredictedIridiumFlares()));
 	connect(ui->iridiumFlaresTreeWidget, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(selectCurrentIridiumFlare(QModelIndex)));
 }
 
+void SatellitesDialog::savePredictedIridiumFlares()
+{
+	QString filter = q_("CSV (Comma delimited)");
+	filter.append(" (*.csv)");
+	QString filePath = QFileDialog::getSaveFileName(0, q_("Save predicted Iridium flares as..."), QDir::homePath() + "/iridium_flares.csv", filter);
+	QFile predictedIridiumFlares(filePath);
+	if (!predictedIridiumFlares.open(QFile::WriteOnly | QFile::Truncate))
+	{
+		qWarning() << "[Satellites]: Unable to open file"
+			   << QDir::toNativeSeparators(filePath);
+		return;
+	}
+
+	QTextStream predictedIridiumFlaresList(&predictedIridiumFlares);
+	predictedIridiumFlaresList.setCodec("UTF-8");
+
+	int count = ui->iridiumFlaresTreeWidget->topLevelItemCount();
+
+	predictedIridiumFlaresList << iridiumFlaresHeader.join(delimiter) << acEndl;
+	for (int i = 0; i < count; i++)
+	{
+		int columns = iridiumFlaresHeader.size();
+		for (int j=0; j<columns; j++)
+		{
+			predictedIridiumFlaresList << ui->iridiumFlaresTreeWidget->topLevelItem(i)->text(j);
+			if (j<columns-1)
+				predictedIridiumFlaresList << delimiter;
+			else
+				predictedIridiumFlaresList << acEndl;
+		}
+	}
+
+	predictedIridiumFlares.close();
+}
+
 void SatellitesDialog::filterListByGroup(int index)
 {
 	if (index < 0)
@@ -408,10 +450,13 @@ void SatellitesDialog::populateAboutPage()
 	QString html = "<html><head></head><body>";
 	html += "<h2>" + q_("Stellarium Satellites Plugin") + "</h2><table width=\"90%\">";
 	html += "<tr width=\"30%\"><td><strong>" + q_("Version") + "</strong></td><td>" + SATELLITES_PLUGIN_VERSION + "</td></td>";
-	html += "<tr><td rowspan=4><strong>" + q_("Authors") + "</strong></td><td>Matthew Gates &lt;matthewg42@gmail.com&gt;</td></td>";
+	html += "<tr><td><strong>" + q_("License") + ":</strong></td><td>" + SATELLITES_PLUGIN_LICENSE + "</td></tr>";
+	html += "<tr><td rowspan=2><strong>" + q_("Authors") + "</strong></td><td>Matthew Gates &lt;matthewg42@gmail.com&gt;</td></td>";
 	html += "<tr><td>Jose Luis Canales &lt;jlcanales.gasco@gmail.com&gt;</td></tr>";
-	html += "<tr><td>Bogdan Marinov &lt;bogdan.marinov84@gmail.com&gt;</td></tr>";
-	html += "<tr><td>Nick Fedoseev &lt;nick.ut2uz@gmail.com&gt; (" + q_("Iridium flares") + ")</td></tr></table>";
+	html += "<tr><td rowspan=4><strong>" + q_("Contributors") + "</strong></td><td>Bogdan Marinov &lt;bogdan.marinov84@gmail.com&gt;</td></tr>";
+	html += "<tr><td>Nick Fedoseev &lt;nick.ut2uz@gmail.com&gt; (" + q_("Iridium flares") + ")</td></tr>";
+	html += "<tr><td>Alexander Wolf &lt;alex.v.wolf@gmail.com&gt;</td></tr>";
+	html += "<tr><td>Georg Zotti</td></tr></table>";
 
 	html += "<p>" + q_("The Satellites plugin predicts the positions of artificial satellites in Earth orbit.") + "</p>";
 
@@ -940,14 +985,15 @@ void SatellitesDialog::enableSatelliteDataForm(bool enabled)
 
 void SatellitesDialog::setIridiumFlaresHeaderNames()
 {
-	QStringList headerStrings;
-	headerStrings << q_("Time");
-	headerStrings << q_("Brightness");
-	headerStrings << q_("Altitude");
-	headerStrings << q_("Azimuth");
-	headerStrings << q_("Satellite");
+	iridiumFlaresHeader.clear();
 
-	ui->iridiumFlaresTreeWidget->setHeaderLabels(headerStrings);
+	iridiumFlaresHeader << q_("Time");
+	iridiumFlaresHeader << q_("Brightness");
+	iridiumFlaresHeader << q_("Altitude");
+	iridiumFlaresHeader << q_("Azimuth");
+	iridiumFlaresHeader << q_("Satellite");
+
+	ui->iridiumFlaresTreeWidget->setHeaderLabels(iridiumFlaresHeader);
 
 	// adjust the column width
 	for(int i = 0; i < IridiumFlaresCount; ++i)
