@@ -38,7 +38,7 @@ TelescopeClientDirectLx200::TelescopeClientDirectLx200 (const QString &name, con
 	: TelescopeClient(name)
 	, time_delay(0)
 	, equinox(eq)
-	, lx200(NULL)
+	, lx200(Q_NULLPTR)
 	, long_format_used(false)
 	, answers_received(false)
 	, last_ra(0)
@@ -98,8 +98,10 @@ TelescopeClientDirectLx200::TelescopeClientDirectLx200 (const QString &name, con
 }
 
 //! queues a GOTO command
-void TelescopeClientDirectLx200::telescopeGoto(const Vec3d &j2000Pos)
+void TelescopeClientDirectLx200::telescopeGoto(const Vec3d &j2000Pos, StelObjectP selectObject)
 {
+	Q_UNUSED(selectObject);
+
 	if (!isConnected())
 		return;
 
@@ -107,7 +109,7 @@ void TelescopeClientDirectLx200::telescopeGoto(const Vec3d &j2000Pos)
 	if (equinox == EquinoxJNow)
 	{
 		const StelCore* core = StelApp::getInstance().getCore();
-		position = core->j2000ToEquinoxEqu(j2000Pos);
+		position = core->j2000ToEquinoxEqu(j2000Pos, StelCore::RefractionOff);
 	}
 
 	//if (writeBufferEnd - writeBuffer + 20 < (int)sizeof(writeBuffer))
@@ -241,7 +243,7 @@ void TelescopeClientDirectLx200::sendPosition(unsigned int ra_int, int dec_int,
 	if (equinox == EquinoxJNow)
 	{
 		const StelCore* core = StelApp::getInstance().getCore();
-		j2000Position = core->equinoxEquToJ2000(position);
+		j2000Position = core->equinoxEquToJ2000(position, StelCore::RefractionOff);
 	}
 	interpolatedPosition.add(j2000Position, getNow(), server_micros, status);
 }
