@@ -245,6 +245,8 @@ StelApp::StelApp(StelMainView *parent)
 	, gl(Q_NULLPTR)
 	, flagShowDecimalDegrees(false)
 	, flagUseAzimuthFromSouth(false)
+	, flagUseFormattingOutput(false)
+	, flagUseCCSDesignation(false)
 	#ifdef ENABLE_SPOUT
 	, spoutSender(Q_NULLPTR)
 	#endif
@@ -403,6 +405,8 @@ void StelApp::init(QSettings* conf)
 	confSettings = conf;
 
 	devicePixelsPerPixel = QOpenGLContext::currentContext()->screen()->devicePixelRatio();
+	if (devicePixelsPerPixel>1)
+		qDebug() << "Detected a high resolution device! Device pixel ratio:" << devicePixelsPerPixel;
 
 	setBaseFontSize(confSettings->value("gui/base_font_size", 13).toInt());
 	
@@ -545,6 +549,8 @@ void StelApp::init(QSettings* conf)
 
 	setFlagShowDecimalDegrees(confSettings->value("gui/flag_show_decimal_degrees", false).toBool());
 	setFlagSouthAzimuthUsage(confSettings->value("gui/flag_use_azimuth_from_south", false).toBool());
+	setFlagUseFormattingOutput(confSettings->value("gui/flag_use_formatting_output", false).toBool());
+	setFlagUseCCSDesignation(confSettings->value("gui/flag_use_ccs_designations", false).toBool());
 
 	// Animation
 	animationScale = confSettings->value("gui/pointer_animation_speed", 1.f).toFloat();
@@ -869,6 +875,16 @@ void StelApp::setFlagShowDecimalDegrees(bool b)
 	flagShowDecimalDegrees = b;
 }
 
+void StelApp::setFlagUseFormattingOutput(bool b)
+{
+	flagUseFormattingOutput = b;
+}
+
+void StelApp::setFlagUseCCSDesignation(bool b)
+{
+	flagUseCCSDesignation = b;
+}
+
 // Update translations and font for sky everywhere in the program
 void StelApp::updateI18n()
 {
