@@ -232,8 +232,8 @@ public:
 
 protected:
 
-	//! Format the positional info string contain J2000/of date/altaz/hour angle positions for the object
-	QString getPositionInfoString(const StelCore *core, const InfoStringGroup& flags) const;
+	//! Format the positional info string contain J2000/of date/altaz/hour angle positions and constellation, sidereal time, etc. for the object
+	QString getCommonInfoString(const StelCore *core, const InfoStringGroup& flags) const;
 
 	//! Apply post processing on the info string
 	void postProcessInfoString(QString& str, const InfoStringGroup& flags) const;
