@@ -122,6 +122,7 @@ void StelProjector::init(const StelProjectorParams& params)
 	flipVert = params.flipVert ? -1.f : 1.f;
 	viewportFovDiameter = params.viewportFovDiameter * devicePixelsPerPixel;
 	pixelPerRad = 0.5f * viewportFovDiameter / fovToViewScalingFactor(params.fov*(M_PI/360.f));
+	widthStretch = params.widthStretch;
 	computeBoundingCap();
 }
 
@@ -165,6 +166,11 @@ Vec2f StelProjector::getViewportCenter() const
 	return Vec2f(viewportCenter[0]-viewportXywh[0],viewportCenter[1]-viewportXywh[1]);
 }
 
+Vec2f StelProjector::getViewportCenterOffset() const
+{
+	return viewportCenterOffset;
+}
+
 int StelProjector::getViewportPosX() const
 {
 	return viewportXywh[0];
