@@ -19,10 +19,9 @@
 #ifndef _STELSKYPOLYGON_HPP_
 #define _STELSKYPOLYGON_HPP_
 
-#include "MultiLevelJsonBase.hpp"
 #include "StelSphereGeometry.hpp"
+#include "MultiLevelJsonBase.hpp"
 #include "StelSkyImageTile.hpp"
-
 #include <QTimeLine>
 
 class StelCore;
@@ -37,7 +36,7 @@ public:
 	StelSkyPolygon() {initCtor();}
 
 	//! Constructor
-	StelSkyPolygon(const QString& url, StelSkyPolygon* parent=NULL);
+	StelSkyPolygon(const QString& url, StelSkyPolygon* parent=Q_NULLPTR);
 	//! Constructor
 	StelSkyPolygon(const QVariantMap& map, StelSkyPolygon* parent);
 
@@ -45,7 +44,7 @@ public:
 	~StelSkyPolygon();
 
 	//! Draw the image on the screen.
-	void draw(StelCore* core, class StelRenderer* renderer, StelProjectorP projector, float opacity=1.);
+	void draw(StelCore* core, StelPainter& sPainter, float opacity=1.);
 
 	//! Return the dataset credits to use in the progress bar
 	DataSetCredits getDataSetCredits() const {return dataSetCredits;}
@@ -88,7 +87,7 @@ private:
 
 	//! Draw the polygon on the screen.
 	//! @return true if the tile was actually displayed
-	bool drawTile(class StelRenderer* renderer, StelProjectorP projector);
+	bool drawTile(StelCore* core);
 
 	//! Return the minimum resolution
 	double getMinResolution() const {return minResolution;}
