@@ -21,17 +21,6 @@
 #include "StelFileMgr.hpp"
 #include "StelUtils.hpp"
 
-#include <cstdio>
-#include <algorithm>
-#include <fstream>
-#include <clocale>
-#include <cstdlib>
-#include <QtGlobal>
-#ifdef Q_OS_WIN
-#include <winsock2.h>
-#include <windows.h>
-#endif
-
 #include <QFile>
 #include <QDebug>
 #include <QStringList>
@@ -46,7 +35,7 @@ QMap<QString, QString> StelTranslator::iso639codes;
 QString StelTranslator::systemLangName;
 
 // Use system locale language by default
-StelTranslator* StelTranslator::globalTranslator = NULL;
+StelTranslator* StelTranslator::globalTranslator = Q_NULLPTR;
 
 StelTranslator::StelTranslator(const QString& adomain, const QString& alangName)
 	: domain(adomain),
@@ -55,15 +44,15 @@ StelTranslator::StelTranslator(const QString& adomain, const QString& alangName)
 	translator = new QTranslator();
 	bool res = translator->load(StelFileMgr::getLocaleDir()+"/"+adomain+"/"+getTrueLocaleName()+".qm");
 	if (!res)
-		qWarning() << "Couldn't load translations for language " << getTrueLocaleName();
+		qWarning() << "Couldn't load translations for language " << getTrueLocaleName() << "in section" << adomain;
 	if (translator->isEmpty())
-		qWarning() << "Empty translation file for language " << getTrueLocaleName();
+		qWarning() << "Empty translation file for language " << getTrueLocaleName() << "in section" << adomain;
 }
 
 StelTranslator::~StelTranslator()
 {
 	delete translator;
-	translator = 0;
+	translator = Q_NULLPTR;
 }
 
 QString StelTranslator::qtranslate(const QString& s, const QString& c) const
@@ -88,7 +77,7 @@ void StelTranslator::init(const QString& fileName)
 	StelTranslator::initSystemLanguage();
 	StelTranslator::initIso639_1LanguageCodes(fileName);
 	
-	Q_ASSERT(StelTranslator::globalTranslator==NULL);
+	Q_ASSERT(StelTranslator::globalTranslator==Q_NULLPTR);
 	StelTranslator::globalTranslator = new StelTranslator("stellarium", "system");
 }
 
