@@ -75,14 +75,15 @@ QString CustomObject::getInfoString(const StelCore* core, const InfoStringGroup&
 
 	if (flags&ObjectType)
 	{
+		QString type = q_("custom object");
 		if (isMarker)
-			oss << q_("Type: <b>%1</b>").arg(q_("custom marker")) << "<br />";
-		else
-			oss << q_("Type: <b>%1</b>").arg(q_("custom object")) << "<br />";
+			type = q_("custom marker");
+
+		oss << QString("%1: <b>%2</b>").arg(q_("Type"), type) << "<br />";
 	}
 
 	// Ra/Dec etc.
-	oss << getPositionInfoString(core, flags);
+	oss << getCommonInfoString(core, flags);
 	postProcessInfoString(str, flags);
 	return str;
 }
