@@ -150,7 +150,7 @@ void SolarSystem::init()
 
 	// Compute position and matrix of sun and all the satellites (ie planets)
 	// for the first initialization Q_ASSERT that center is sun center (only impacts on light speed correction)	
-	computePositions(StelApp::getInstance().getCore()->getJDE());
+	computePositions(StelApp::getInstance().getCore()->getJDE(), getSun());
 
 	setSelected("");	// Fix a bug on macosX! Thanks Fumio!
 	setFlagMoonScale(conf->value("viewing/flag_moon_scaled", conf->value("viewing/flag_init_moon_scaled", "false").toBool()).toBool());  // name change
@@ -404,6 +404,7 @@ void cometOrbitPosFunc(double jd,double xyz[3], void* userDataPtr)
 void SolarSystem::loadPlanets()
 {
 	minorBodies.clear();
+	systemMinorBodies.clear();
 	qDebug() << "Loading Solar System data (1: planets and moons) ...";
 	QString solarSystemFile = StelFileMgr::findFile("data/ssystem_major.ini");
 	if (solarSystemFile.isEmpty())
@@ -449,8 +450,8 @@ void SolarSystem::loadPlanets()
 					p->satellites.clear();
 					p.clear();
 				}
-			}
-			systemPlanets.clear();
+			}			
+			systemPlanets.clear();			
 			//Memory leak? What's the proper way of cleaning shared pointers?
 
 			// TODO: 0.16pre what about the orbits list?
@@ -477,8 +478,21 @@ void SolarSystem::loadPlanets()
 			shadowPlanetCount++;
 }
 
+unsigned char SolarSystem::BvToColorIndex(float bV)
+{
+	double dBV = bV;
+	dBV *= 1000.0;
+	if (dBV < -500)
+		dBV = -500;
+	else if (dBV > 3499)
+		dBV = 3499;
+
+	return (unsigned int)floor(0.5+127.0*((500.0+dBV)/4000.0));
+}
+
 bool SolarSystem::loadPlanets(const QString& filePath)
 {
+	StelSkyDrawer* skyDrawer = StelApp::getInstance().getCore()->getSkyDrawer();
 	qDebug() << "Loading from :"  << filePath;
 	int readOk = 0;
 	QSettings pd(filePath, StelIniFormat);
@@ -946,10 +960,18 @@ bool SolarSystem::loadPlanets(const QString& filePath)
 		if ((type == "asteroid" || type == "dwarf planet" || type == "cubewano" || type == "plutino" || type == "scattered disc object" || type == "Oort cloud object") && !englishName.contains("Pluto"))
 		{
 			minorBodies << englishName;
+
+			Vec3f color = Vec3f(1.f, 1.f, 1.f);
+			float bV = pd.value(secname+"/color_index_bv", 99.f).toFloat();
+			if (bV<99.f)
+				color = skyDrawer->indexToColor(BvToColorIndex(bV))*0.75f;
+			else
+				color = StelUtils::strToVec3f(pd.value(secname+"/color", "1.0,1.0,1.0").toString());
+
 			p = PlanetP(new MinorPlanet(englishName,
 						    pd.value(secname+"/radius").toDouble()/AU,
 						    pd.value(secname+"/oblateness", 0.0).toDouble(),
-						    StelUtils::strToVec3f(pd.value(secname+"/color", "1.0,1.0,1.0").toString()), // halo color
+						    color, // halo color
 						    pd.value(secname+"/albedo", 0.25f).toFloat(),
 						    pd.value(secname+"/roughness",0.9f).toFloat(),
 						    pd.value(secname+"/tex_map", "nomap.png").toString(),
@@ -993,7 +1015,10 @@ bool SolarSystem::loadPlanets(const QString& filePath)
 			}
 
 			mp->setSemiMajorAxis(pd.value(secname+"/orbit_SemiMajorAxis", 0).toDouble());
+			mp->setColorIndexBV(bV);
+			mp->setSpectralType(pd.value(secname+"/spec_t", "").toString(), pd.value(secname+"/spec_b", "").toString());
 
+			systemMinorBodies.push_back(p);
 		}
 		else if (type == "comet")
 		{
@@ -1042,6 +1067,7 @@ bool SolarSystem::loadPlanets(const QString& filePath)
 			{
 				mp->setSemiMajorAxis(pericenterDistance / (1.0-eccentricity));
 			}
+			systemMinorBodies.push_back(p);
 		}
 		else
 		{
@@ -1069,6 +1095,13 @@ bool SolarSystem::loadPlanets(const QString& filePath)
 					       pd.value(secname+"/halo", true).toBool(),          // GZ new default. Avoids clutter in ssystem.ini.
 					       type));
 			p->absoluteMagnitude = pd.value(secname+"/absolute_magnitude", -99.).toDouble();
+
+			// Moon designation (planet index + IAU moon number)
+			QString moonDesignation = pd.value(secname+"/iau_moon_number", "").toString();
+			if (!moonDesignation.isEmpty())
+			{
+				p->setIAUMoonNumber(moonDesignation);
+			}
 		}
 
 
@@ -1153,7 +1186,7 @@ bool SolarSystem::loadPlanets(const QString& filePath)
 
 // Compute the position for every elements of the solar system.
 // The order is not important since the position is computed relatively to the mother body
-void SolarSystem::computePositions(double dateJDE, const Vec3d& observerPos)
+void SolarSystem::computePositions(double dateJDE, PlanetP observerPlanet)
 {
 	if (flagLightTravelTime)
 	{
@@ -1161,27 +1194,25 @@ void SolarSystem::computePositions(double dateJDE, const Vec3d& observerPos)
 		{
 			p->computePositionWithoutOrbits(dateJDE);
 		}
-		// BEGIN HACK: 0.16.0pre for solar aberration/light time correction: (This fixes eclipse bug LP:#1275092)
-		Vec3d earthPosJDE=getEarth()->getHeliocentricEclipticPos();
-		const double earthDist=earthPosJDE.length();
-		getEarth()->computePosition(dateJDE-earthDist * (AU / (SPEED_OF_LIGHT * 86400)));
-		Vec3d earthPosJDEbefore=getEarth()->getHeliocentricEclipticPos();
-		getSun()->setHeliocentricEclipticPos(earthPosJDE-earthPosJDEbefore);
+		// BEGIN HACK: 0.16.0post for solar aberration/light time correction
+		// This fixes eclipse bug LP:#1275092) and outer planet rendering bug (LP:#1699648) introduced by the first fix in 0.16.0.
+		// We compute a "light time corrected position" for the sun and apply it only for rendering, not for other computations.
+		// A complete solution should likely "just" implement aberration for all objects.
+		const Vec3d obsPosJDE=observerPlanet->getHeliocentricEclipticPos();
+		const double obsDist=obsPosJDE.length();
 
-		// We must reset Earth for the next step!
-		getEarth()->computePosition(dateJDE);
-		// END HACK FOR SOLAR LOGHT TIME/ABERRATION
+		observerPlanet->computePosition(dateJDE-obsDist * (AU / (SPEED_OF_LIGHT * 86400.)));
+		const Vec3d obsPosJDEbefore=observerPlanet->getHeliocentricEclipticPos();
+		lightTimeSunPosition=obsPosJDE-obsPosJDEbefore;
+
+		// We must reset observerPlanet for the next step!
+		observerPlanet->computePosition(dateJDE);
+		// END HACK FOR SOLAR LIGHT TIME/ABERRATION
 		foreach (PlanetP p, systemPlanets)
 		{
-			const double light_speed_correction = (p->getHeliocentricEclipticPos()-observerPos).length() * (AU / (SPEED_OF_LIGHT * 86400));
+			const double light_speed_correction = (p->getHeliocentricEclipticPos()-obsPosJDE).length() * (AU / (SPEED_OF_LIGHT * 86400.));
 			p->computePosition(dateJDE-light_speed_correction);
 		}
-
-		// BEGIN HACK PART 2
-		getSun()->setHeliocentricEclipticPos(earthPosJDE-earthPosJDEbefore);
-		// END HACK PART 2
-
-
 	}
 	else
 	{
@@ -1189,8 +1220,9 @@ void SolarSystem::computePositions(double dateJDE, const Vec3d& observerPos)
 		{
 			p->computePosition(dateJDE);
 		}
+		lightTimeSunPosition.set(0.,0.,0.);
 	}
-	computeTransMatrices(dateJDE, observerPos);
+	computeTransMatrices(dateJDE, observerPlanet->getHeliocentricEclipticPos());
 }
 
 // Compute the transformation matrix for every elements of the solar system.
@@ -1330,6 +1362,17 @@ PlanetP SolarSystem::searchByEnglishName(QString planetEnglishName) const
 	return PlanetP();
 }
 
+PlanetP SolarSystem::searchMinorPlanetByEnglishName(QString planetEnglishName) const
+{
+	foreach (const PlanetP& p, systemMinorBodies)
+	{
+		if (p->getCommonEnglishName() == planetEnglishName)
+			return p;
+	}
+	return PlanetP();
+}
+
+
 StelObjectP SolarSystem::searchByNameI18n(const QString& planetNameI18) const
 {
 	foreach (const PlanetP& p, systemPlanets)
@@ -1345,7 +1388,7 @@ StelObjectP SolarSystem::searchByName(const QString& name) const
 {
 	foreach (const PlanetP& p, systemPlanets)
 	{
-		if (p->getEnglishName() == name)
+		if (p->getEnglishName() == name || p->getCommonEnglishName() == name)
 			return qSharedPointerCast<StelObject>(p);
 	}
 	return StelObjectP();
@@ -1354,6 +1397,8 @@ StelObjectP SolarSystem::searchByName(const QString& name) const
 float SolarSystem::getPlanetVMagnitude(QString planetName, bool withExtinction) const
 {
 	PlanetP p = searchByEnglishName(planetName);
+	if (p.isNull()) // Possible was asked the common name of minor planet?
+		p = searchMinorPlanetByEnglishName(planetName);
 	float r = 0.f;
 	if (withExtinction)
 		r = p->getVMagnitudeWithExtinction(StelApp::getInstance().getCore());
@@ -1365,12 +1410,16 @@ float SolarSystem::getPlanetVMagnitude(QString planetName, bool withExtinction)
 QString SolarSystem::getPlanetType(QString planetName) const
 {
 	PlanetP p = searchByEnglishName(planetName);
+	if (p.isNull()) // Possible was asked the common name of minor planet?
+		p = searchMinorPlanetByEnglishName(planetName);
 	return p->getPlanetTypeString();
 }
 
 double SolarSystem::getDistanceToPlanet(QString planetName) const
 {
 	PlanetP p = searchByEnglishName(planetName);
+	if (p.isNull()) // Possible was asked the common name of minor planet?
+		p = searchMinorPlanetByEnglishName(planetName);
 	double r = 0.f;
 	r = p->getDistance();
 	return r;
@@ -1379,6 +1428,8 @@ double SolarSystem::getDistanceToPlanet(QString planetName) const
 double SolarSystem::getElongationForPlanet(QString planetName) const
 {
 	PlanetP p = searchByEnglishName(planetName);
+	if (p.isNull()) // Possible was asked the common name of minor planet?
+		p = searchMinorPlanetByEnglishName(planetName);
 	double r = 0.f;
 	r = p->getElongation(StelApp::getInstance().getCore()->getObserverHeliocentricEclipticPos());
 	return r;
@@ -1387,6 +1438,8 @@ double SolarSystem::getElongationForPlanet(QString planetName) const
 double SolarSystem::getPhaseAngleForPlanet(QString planetName) const
 {
 	PlanetP p = searchByEnglishName(planetName);
+	if (p.isNull()) // Possible was asked the common name of minor planet?
+		p = searchMinorPlanetByEnglishName(planetName);
 	double r = 0.f;
 	r = p->getPhaseAngle(StelApp::getInstance().getCore()->getObserverHeliocentricEclipticPos());
 	return r;
@@ -1395,6 +1448,8 @@ double SolarSystem::getPhaseAngleForPlanet(QString planetName) const
 float SolarSystem::getPhaseForPlanet(QString planetName) const
 {
 	PlanetP p = searchByEnglishName(planetName);
+	if (p.isNull()) // Possible was asked the common name of minor planet?
+		p = searchMinorPlanetByEnglishName(planetName);
 	float r = 0.f;
 	r = p->getPhase(StelApp::getInstance().getCore()->getObserverHeliocentricEclipticPos());
 	return r;
@@ -2082,9 +2137,7 @@ void SolarSystem::setFlagMinorBodyScale(bool b)
 		foreach(PlanetP p, systemPlanets)
 		{
 			if(p == moon) continue;
-			if (p->getPlanetType()!=Planet::isPlanet
-					&& p->getPlanetType()!=Planet::isStar
-					)
+			if (p->getPlanetType()!=Planet::isPlanet && p->getPlanetType()!=Planet::isStar)
 				p->setSphereScale(newScale);
 		}
 		emit flagMinorBodyScaleChanged(b);
@@ -2102,9 +2155,7 @@ void SolarSystem::setMinorBodyScale(double f)
 			foreach(PlanetP p, systemPlanets)
 			{
 				if(p == moon) continue;
-				if (p->getPlanetType()!=Planet::isPlanet
-						&& p->getPlanetType()!=Planet::isStar
-						)
+				if (p->getPlanetType()!=Planet::isPlanet && p->getPlanetType()!=Planet::isStar)
 					p->setSphereScale(minorBodyScale);
 			}
 		}
@@ -2123,7 +2174,7 @@ QStringList SolarSystem::getAllPlanetEnglishNames() const
 {
 	QStringList res;
 	foreach (const PlanetP& p, systemPlanets)
-		res.append(p->englishName);
+		res.append(p->getEnglishName());
 	return res;
 }
 
@@ -2131,10 +2182,19 @@ QStringList SolarSystem::getAllPlanetLocalizedNames() const
 {
 	QStringList res;
 	foreach (const PlanetP& p, systemPlanets)
-		res.append(p->nameI18);
+		res.append(p->getNameI18n());
 	return res;
 }
 
+QStringList SolarSystem::getAllMinorPlanetCommonEnglishNames() const
+{
+	QStringList res;
+	foreach (const PlanetP& p, systemMinorBodies)
+		res.append(p->getCommonEnglishName());
+	return res;
+}
+
+
 // GZ TODO: This could be modified to only delete&reload the minor objects. For now, we really load both parts again like in the 0.10?-0.15 series.
 void SolarSystem::reloadPlanets()
 {
@@ -2190,6 +2250,7 @@ void SolarSystem::reloadPlanets()
 		p.clear();
 	}
 	systemPlanets.clear();
+	systemMinorBodies.clear();
 	// Memory leak? What's the proper way of cleaning shared pointers?
 
 	// Also delete Comet textures (loaded in loadPlanets()
@@ -2198,7 +2259,7 @@ void SolarSystem::reloadPlanets()
 
 	// Re-load the ssystem_major.ini and ssystem_minor.ini file
 	loadPlanets();	
-	computePositions(core->getJDE());
+	computePositions(core->getJDE(), getSun());
 	setSelected("");
 	recreateTrails();
 	
@@ -2329,7 +2390,7 @@ QString SolarSystem::getOrbitColorStyle() const
 
 double SolarSystem::getEclipseFactor(const StelCore* core) const
 {
-	Vec3d Lp = sun->getEclipticPos();
+	Vec3d Lp = getLightTimeSunPosition();  //sun->getEclipticPos();
 	Vec3d P3 = core->getObserverHeliocentricEclipticPos();
 	const double RS = sun->getRadius();
 
@@ -2343,7 +2404,7 @@ double SolarSystem::getEclipseFactor(const StelCore* core) const
 		Mat4d trans;
 		planet->computeModelMatrix(trans);
 
-		const Vec3d C = trans * Vec3d(0, 0, 0);
+		const Vec3d C = trans * Vec3d(0., 0., 0.);
 		const double radius = planet->getRadius();
 
 		Vec3d v1 = Lp - P3;
@@ -2360,27 +2421,23 @@ double SolarSystem::getEclipseFactor(const StelCore* core) const
 		const double d = ( v1 - v2 ).length();
 
 		if(planet->englishName == "Moon")
-			v1 = planet->getHeliocentricEclipticPos();
+			v1 = planet->getHeliocentricEclipticPos(); // ??? This assignment is dead code!
 
 		double illumination;
 
-		// distance too far
-		if(d >= R + r)
+		if(d >= R + r) // distance too far
 		{
 			illumination = 1.0;
 		}
-		// umbra
-		else if(r >= R + d)
+		else if(d <= r - R) // umbra
 		{
 			illumination = 0.0;
 		}
-		// penumbra completely inside
-		else if(d + r <= R)
+		else if(d <= R - r) // penumbra completely inside
 		{
 			illumination = 1.0 - r * r / (R * R);
 		}
-		// penumbra partially inside
-		else
+		else // penumbra partially inside
 		{
 			const double x = (R * R + d * d - r * r) / (2.0 * d);
 
@@ -2401,26 +2458,19 @@ double SolarSystem::getEclipseFactor(const StelCore* core) const
 	return final_illumination;
 }
 
-bool SolarSystem::removePlanet(QString name)
+bool SolarSystem::removeMinorPlanet(QString name)
 {
-	PlanetP candidate = searchByEnglishName(name);
+	PlanetP candidate = searchMinorPlanetByEnglishName(name);
 	if (!candidate)
 	{
 		qWarning() << "Cannot remove planet " << name << ": Not found.";
 		return false;
 	}
-	// TODO: In case we want major bodies or Pluto to be deleted, think about proper handling of moons!
-	//candidate->satellites.clear();
-	if (candidate->pType < Planet::isAsteroid)
-	{
-		qWarning() << "REMOVING MAJOR OBJECT:" << name;
-		qWarning() << "              This is likely not what you want, but will be accepted.";
-		Q_ASSERT(0);
-	}
 	Orbit* orbPtr=(Orbit*) candidate->orbitPtr;
 	if (orbPtr)
 		orbits.removeOne(orbPtr);
 	systemPlanets.removeOne(candidate);
+	systemMinorBodies.removeOne(candidate);
 	candidate.clear();
 	return true;
 }
