@@ -95,6 +95,8 @@ private slots:
 	void usageButtonsBackgroundChanged(bool b);
 
 	void updateStartPointForAzimuth(bool b);
+	void updateSettingFormattingOutput(bool b);
+	void updateSettingCCSDesignations(bool b);
 
 	void newStarCatalogData();
 	void downloadStars();
