@@ -32,7 +32,7 @@
 #include <QLineEdit>
 
 DateTimeDialog::DateTimeDialog(QObject* parent) :
-	StelDialog(parent),
+	StelDialog("DateTime", parent),
 	year(0),
 	month(0),
 	day(0),
@@ -42,26 +42,30 @@ DateTimeDialog::DateTimeDialog(QObject* parent) :
 	jd(0)
 {
 	ui = new Ui_dateTimeDialogForm;
-	dialogName = "DateTime";
 }
 
 DateTimeDialog::~DateTimeDialog()
 {
 	delete ui;
-	ui=NULL;
+	ui=Q_NULLPTR;
 }
 
 void DateTimeDialog::createDialogContent()
 {
 	ui->setupUi(dialog);
-	double jd = StelApp::getInstance().getCore()->getJD();
-	// UTC -> local tz
-	setDateTime(jd + (StelApp::getInstance().getLocaleMgr().getGMTShift(jd)/24.0));
+	StelCore *core = StelApp::getInstance().getCore();
+	setDateTime(core->getJD());
 
 	connect(&StelApp::getInstance(), SIGNAL(languageChanged()), this, SLOT(retranslate()));
 	connect(ui->closeStelWindow, SIGNAL(clicked()), this, SLOT(close()));
 	connect(ui->TitleBar, SIGNAL(movedTo(QPoint)), this, SLOT(handleMovedTo(QPoint)));
 
+	// Use ISO 8601 to date formatting
+	// See details: https://bugs.launchpad.net/stellarium/+bug/1655630
+	QString delimiter = QChar(0x2012);
+	ui->dateDelimiterLabel1->setText(delimiter);
+	ui->dateDelimiterLabel2->setText(delimiter);
+
 	connectSpinnerEvents();
 }
 
@@ -120,7 +124,6 @@ bool DateTimeDialog::validJd(double jday)
 {
 	pushToWidgets();
 	StelApp::getInstance().getCore()->setJD(jday);
-
 	return true;
 }
 
@@ -151,6 +154,7 @@ void DateTimeDialog::yearChanged(int newyear)
 	if ( year != newyear )
 	{
 		valid( newyear, month, day, hour, minute, second );
+		emit StelApp::getInstance().getCore()->dateChanged();
 	}
 }
 
@@ -159,6 +163,7 @@ void DateTimeDialog::monthChanged(int newmonth)
 	if ( month != newmonth )
 	{
 		valid( year, newmonth, day, hour, minute, second );
+		emit StelApp::getInstance().getCore()->dateChanged();
 	}
 }
 
@@ -166,6 +171,7 @@ void DateTimeDialog::dayChanged(int newday)
 {
 	int delta = newday - day;
 	validJd(jd + delta);
+	emit StelApp::getInstance().getCore()->dateChanged();
 }
 
 void DateTimeDialog::hourChanged(int newhour)
@@ -202,7 +208,7 @@ double DateTimeDialog::newJd()
 {
 	double cjd;
 	StelUtils::getJDFromDate(&cjd, year, month, day, hour, minute, second);
-	cjd -= (StelApp::getInstance().getLocaleMgr().getGMTShift(cjd)/24.0); // local tz -> UTC
+	cjd -= (StelApp::getInstance().getCore()->getUTCOffset(cjd)/24.0); // local tz -> UTC
 
 	return cjd;
 }
@@ -232,7 +238,7 @@ void DateTimeDialog::setDateTime(double newJd)
 {
 	if (this->visible()) {
 		// JD and MJD should be at the UTC scale on the window!
-		double newJdC = newJd + StelApp::getInstance().getLocaleMgr().getGMTShift(newJd)/24.0; // UTC -> local tz
+		double newJdC = newJd + StelApp::getInstance().getCore()->getUTCOffset(newJd)/24.0; // UTC -> local tz
 		StelUtils::getDateFromJulianDay(newJdC, &year, &month, &day);
 		StelUtils::getTimeFromJulianDay(newJdC, &hour, &minute, &second);
 		jd = newJd;
