@@ -132,6 +132,10 @@ class Translations
 		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
 		N_("Supernova remnants");
 		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Supernova candidates");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
+		N_("Supernova remnant candidates");
+		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
 		N_("Interstellar matter");
 		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
 		N_("Emission objects");
@@ -149,6 +153,12 @@ class Translations
 		N_("Possible Planetary Nebulae");
 		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
 		N_("Protoplanetary Nebulae");
+		// TRANSLATORS: Type of stars (for "Lists" in the search tool)
+		N_("Symbiotic stars");
+		// TRANSLATORS: Type of stars (for "Lists" in the search tool)
+		N_("Emission-line stars");
+		// TRANSLATORS: Type of stars (for "Lists" in the search tool)
+		N_("Clusters of galaxies");
 		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
 		N_("Messier Catalogue");
 		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
@@ -181,6 +191,12 @@ class Translations
 		N_("The Catalogue of Interacting Galaxies");
 		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
 		N_("The Catalogue of Galactic Planetary Nebulae");
+		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
+		N_("The Strasbourg-ESO Catalogue of Galactic Planetary Nebulae");
+		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
+		N_("A catalogue of Galactic supernova remnants");
+		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
+		N_("A Catalog of Rich Clusters of Galaxies");
 		// TRANSLATORS: Type of objects (for "Lists" in the search tool)
 		N_("Dwarf galaxies");
 		// TRANSLATORS: Catalogue of objects (for "Lists" in the search tool)
@@ -427,6 +443,7 @@ class Translations
 		N_("Directories");
 		N_("Computer");
 		N_("&Open");
+		N_("&Save");
 		N_("File &name:");
 		N_("Copy &Link Location");
 		N_("Abort");
@@ -443,5 +460,15 @@ class Translations
 		N_("Bl&ue:");
 		N_("Select Color");
 		N_("Cursor at %1, %2 Press ESC to cancel");
+		N_("Back");
+		N_("Forward");
+		N_("Parent Directory");
+		N_("Create New Folder");
+		N_("List View");
+		N_("Detail View");
+		N_("Recent Places");
+		N_("%1 already exists.\nDo you want to replace it?");
+		N_("&Yes");
+		N_("&No");
 	}
 };
